%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% Define the Nonlinear Model %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function dzdt = blending(t,z,u)
% Dynamic model of the blending process
% Martha Grover, June 15, 2018
% Parameters
rho = 1000; % Density [kg/m3]
x1 = 0.1;     % Mass fraction of Species A in Inlet Stream 1
x2 = 0;       % Mass fraction of Species A in Inlet Stream 2

% State variables passed in as vector z:
V = z(1);   % Volume [m3]
x = z(2);   % Mass fraction of Species A in the tank (unitless)

% Inputs passed in as vector u:
w1 = u(1);  % Mass flow rate in Stream 1 [kg/s]
w2 = u(2);  % Mass flow rate in Stream 2 [kg/s]
w = u(3);   % Here we set the outlet flow equal to the total inlet flow

% Dynamic equations
dVdt = 1/rho*(w1+w2-w);                     % Change in volume
dxdt = 1/(rho*V)*(w1*(x1-x)+w2*(x2-x));     % Change in mass fraction

% Assemble the two time derivatives back into a vector to pass back
dzdt = [dVdt; dxdt];

end